package com.ruoyi.sapMaterial.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.sapMaterial.mapper.SapMaterialMapper;
import com.ruoyi.sapMaterial.domain.SapMaterial;
import com.ruoyi.sapMaterial.service.ISapMaterialService;

/**
 * 物料管理Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-03-12
 */
@Service
public class SapMaterialServiceImpl implements ISapMaterialService 
{
    @Autowired
    private SapMaterialMapper sapMaterialMapper;

    /**
     * 查询物料管理
     * 
     * @param materialId 物料管理主键
     * @return 物料管理
     */
    @Override
    public SapMaterial selectSapMaterialByMaterialId(Long materialId)
    {
        return sapMaterialMapper.selectSapMaterialByMaterialId(materialId);
    }

    /**
     * 查询物料管理列表
     * 
     * @param sapMaterial 物料管理
     * @return 物料管理
     */
    @Override
    public List<SapMaterial> selectSapMaterialList(SapMaterial sapMaterial)
    {
        return sapMaterialMapper.selectSapMaterialList(sapMaterial);
    }

    /**
     * 新增物料管理
     * 
     * @param sapMaterial 物料管理
     * @return 结果
     */
    @Override
    public int insertSapMaterial(SapMaterial sapMaterial)
    {
        return sapMaterialMapper.insertSapMaterial(sapMaterial);
    }

    /**
     * 修改物料管理
     * 
     * @param sapMaterial 物料管理
     * @return 结果
     */
    @Override
    public int updateSapMaterial(SapMaterial sapMaterial)
    {
        return sapMaterialMapper.updateSapMaterial(sapMaterial);
    }

    /**
     * 批量删除物料管理
     * 
     * @param materialIds 需要删除的物料管理主键
     * @return 结果
     */
    @Override
    public int deleteSapMaterialByMaterialIds(Long[] materialIds)
    {
        return sapMaterialMapper.deleteSapMaterialByMaterialIds(materialIds);
    }

    /**
     * 删除物料管理信息
     * 
     * @param materialId 物料管理主键
     * @return 结果
     */
    @Override
    public int deleteSapMaterialByMaterialId(Long materialId)
    {
        return sapMaterialMapper.deleteSapMaterialByMaterialId(materialId);
    }
}
